Learn R Programming

HeckmanEM (version 0.2-0)

rHeckman: Data generation from the Heckman Selection model (Normal or Student-t)

Description

`rHeckman()` generates a random sample from the Heckman selection model (Normal or Student-t).

Usage

rHeckman(x, w, beta, gamma, sigma2, rho, nu = 4, family = "T")

Value

Return an object with the response (y) and missing values (cc).

Arguments

x

A covariate matrix for the response y.

w

A covariate matrix for the missing indicator cc.

beta

Values for the beta vector.

gamma

Values for the gamma vector.

sigma2

Value for the variance.

rho

Value for the dependence between the response and missing value.

nu

Value for the degrees of freedom.

family

The family to be used (Normal or T).

Examples

Run this code
# \donttest{
n <- 100
rho <- .6
cens <- 0.25
nu <- 4
set.seed(20200527)
w <- cbind(1,runif(n,-1,1),rnorm(n))
x <- cbind(w[,1:2])

family <- "T"
c <- qt(cens, df=nu)

sigma2 <- 1
beta <- c(1,0.5)
gamma<- c(1,0.3,-.5)
gamma[1] <- -c*sqrt(sigma2)

data <- rHeckman(x,w,beta,gamma,sigma2,rho,nu,family=family)
# }

Run the code above in your browser using DataLab